@@ -16,19 +16,19 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with DIJITSO. If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import unicode_literals
+from pkg_resources import get_distribution
 
 """This is dijitso -- a lightweight distributed just-in-time shared
 library builder."""
 
 __author__ = "Martin Sandve Alnæs"
-__version__ = "2016.2.0"
+__version__ = get_distribution('fenics-dijitso').version
 
 __all__ = ["validate_params", "jit", "extract_factory_function",
            "set_log_level"]
 
 from dijitso.params import validate_params
-from dijitso.jit import jit
+from dijitso.jit import jit, DijitsoError
 from dijitso.jit import extract_factory_function
 from dijitso.log import set_log_level
 
